==> ejc-jltest-impl-3.0.0-20240311.091845-55-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlancEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.business.jltest.orgtest.vo.PlancDetailVO;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 安措费使用计划C
 *
 * @author generator
 */
@TableName("ejc_jltest_planc")
public class PlancEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_code")
    private String billCode; // 安措费使用计划发文字号
    @TableField(value = "plan_name")
    private String planName; // 安措费使用计划发文名称
    @TableField(value = "urgency_degree")
    private Integer urgencyDegree; // 紧急程度（1-一般，2-急，3-特急）
    @TableField(value = "security_class")
    private Integer securityClass; // 密级（1-公开，2-秘密，3-机密，4-绝密）
    @TableField(value = "plan_date")
    private Date planDate; // 安措费使用计划发文日期
    @TableField(value = "plan_mny")
    private BigDecimal planMny; // 拟投入金额
    @TableField(value = "project_id")
    private Long projectId; // 项目
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "project_code")
    private String projectCode; // 项目code
    @TableField(value = "org_id")
    private Long orgId; // 组织
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "org_code")
    private String orgCode; // 组织code
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value = "safeteamc_id")
    private Long safeteamcId; // 安全小组主键
    @TableField(value = "safeteamc_name")
    private String safeteamcName; // 安全小组发文名称
    @TableField(value = "safeteamc_bill_code")
    private String safeteamcBillCode; // 安全小组成立发文字号
    @TableField(value = "safeteamc_date")
    private Date safeteamcDate; // 安全小组发文日期
    @TableField(value = "employee_id")
    private Long employeeId; // 经办人
    @TableField(value = "employee_name")
    private String employeeName; // 经办人名称
    @TableField(value = "submit_employee_id")
    private Long submitEmployeeId; // 提交人
    @TableField(value = "submit_employee_name")
    private String submitEmployeeName; // 提交人名称
    @TableField(value = "department_id")
    private Long departmentId; // 经办部门
    @TableField(value = "department_name")
    private String departmentName; // 经办部门名称
    @TableField(value = "lister_id")
    private Long listerId; // 制表人
    @TableField(value = "lister_name")
    private String listerName; // 制表人名称
    @TableField(value = "memo")
    private String memo; // 安措费使用计发文说明
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value = "submit_date")
    private Date submitDate; // 提交日期

    @TableField(exist = false)
    @SubEntity(serviceName = "plancDetailService", pidName = "planId")
    private List<PlancDetailEntity> plancDetailList = new ArrayList<>(); // 计划明细

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }

    public Integer getUrgencyDegree() {
        return urgencyDegree;
    }

    public void setUrgencyDegree(Integer urgencyDegree) {
        this.urgencyDegree = urgencyDegree;
    }

    public Integer getSecurityClass() {
        return securityClass;
    }

    public void setSecurityClass(Integer securityClass) {
        this.securityClass = securityClass;
    }

    public Date getPlanDate() {
        return planDate;
    }

    public void setPlanDate(Date planDate) {
        this.planDate = planDate;
    }

    public BigDecimal getPlanMny() {
        return planMny;
    }

    public void setPlanMny(BigDecimal planMny) {
        this.planMny = planMny;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public Long getSafeteamcId() {
        return safeteamcId;
    }

    public void setSafeteamcId(Long safeteamcId) {
        this.safeteamcId = safeteamcId;
    }

    public String getSafeteamcName() {
        return safeteamcName;
    }

    public void setSafeteamcName(String safeteamcName) {
        this.safeteamcName = safeteamcName;
    }

    public String getSafeteamcBillCode() {
        return safeteamcBillCode;
    }

    public void setSafeteamcBillCode(String safeteamcBillCode) {
        this.safeteamcBillCode = safeteamcBillCode;
    }

    public Date getSafeteamcDate() {
        return safeteamcDate;
    }

    public void setSafeteamcDate(Date safeteamcDate) {
        this.safeteamcDate = safeteamcDate;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getSubmitEmployeeId() {
        return submitEmployeeId;
    }

    public void setSubmitEmployeeId(Long submitEmployeeId) {
        this.submitEmployeeId = submitEmployeeId;
    }

    public String getSubmitEmployeeName() {
        return submitEmployeeName;
    }

    public void setSubmitEmployeeName(String submitEmployeeName) {
        this.submitEmployeeName = submitEmployeeName;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Date getSubmitDate() {
        return submitDate;
    }

    public void setSubmitDate(Date submitDate) {
        this.submitDate = submitDate;
    }

    public List<PlancDetailEntity> getPlancDetailList() {
        return plancDetailList;
    }

    public void setPlancDetailList(List<PlancDetailEntity> plancDetailList) {
        this.plancDetailList = plancDetailList;
    }

    public Long getListerId() {
        return listerId;
    }

    public void setListerId(Long listerId) {
        this.listerId = listerId;
    }

    public String getListerName() {
        return listerName;
    }

    public void setListerName(String listerName) {
        this.listerName = listerName;
    }
}

==> ejc-jltest-impl-3.0.0-20240328.015927-125-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlancEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.business.jltest.orgtest.vo.PlancDetailVO;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 安措费使用计划C
 *
 * @author generator
 */
@TableName("ejc_jltest_planc")
public class PlancEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "bill_code")
    private String billCode; // 安措费使用计划发文字号
    @TableField(value = "plan_name")
    private String planName; // 安措费使用计划发文名称
    @TableField(value = "urgency_degree")
    private Integer urgencyDegree; // 紧急程度（1-一般，2-急，3-特急）
    @TableField(value = "security_class")
    private Integer securityClass; // 密级（1-公开，2-秘密，3-机密，4-绝密）
    @TableField(value = "plan_date")
    private Date planDate; // 安措费使用计划发文日期
    @TableField(value = "plan_mny")
    private BigDecimal planMny; // 拟投入金额
    @TableField(value = "project_id")
    private Long projectId; // 项目
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "project_code")
    private String projectCode; // 项目code
    @TableField(value = "org_id")
    private Long orgId; // 组织
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "org_code")
    private String orgCode; // 组织code
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value = "safeteamc_id")
    private Long safeteamcId; // 安全小组主键
    @TableField(value = "safeteamc_name")
    private String safeteamcName; // 安全小组发文名称
    @TableField(value = "safeteamc_bill_code")
    private String safeteamcBillCode; // 安全小组成立发文字号
    @TableField(value = "safeteamc_date")
    private Date safeteamcDate; // 安全小组发文日期
    @TableField(value = "employee_id")
    private Long employeeId; // 经办人
    @TableField(value = "employee_name")
    private String employeeName; // 经办人名称
    @TableField(value = "submit_employee_id")
    private Long submitEmployeeId; // 提交人
    @TableField(value = "submit_employee_name")
    private String submitEmployeeName; // 提交人名称
    @TableField(value = "department_id")
    private Long departmentId; // 经办部门
    @TableField(value = "department_name")
    private String departmentName; // 经办部门名称
    @TableField(value = "lister_id")
    private Long listerId; // 制表人
    @TableField(value = "lister_name")
    private String listerName; // 制表人名称
    @TableField(value = "memo")
    private String memo; // 安措费使用计发文说明
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value = "submit_date")
    private Date submitDate; // 提交日期

    @TableField(exist = false)
    private String urgencyDegreeName; //紧急程度翻译

    @TableField(exist = false)
    private String securityClassName; //紧急程度翻译

    @TableField(exist = false)
    @SubEntity(serviceName = "plancDetailService", pidName = "planId")
    private List<PlancDetailEntity> plancDetailList = new ArrayList<>(); // 计划明细

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }

    public Integer getUrgencyDegree() {
        return urgencyDegree;
    }

    public void setUrgencyDegree(Integer urgencyDegree) {
        this.urgencyDegree = urgencyDegree;
    }

    public Integer getSecurityClass() {
        return securityClass;
    }

    public void setSecurityClass(Integer securityClass) {
        this.securityClass = securityClass;
    }

    public Date getPlanDate() {
        return planDate;
    }

    public void setPlanDate(Date planDate) {
        this.planDate = planDate;
    }

    public BigDecimal getPlanMny() {
        return planMny;
    }

    public void setPlanMny(BigDecimal planMny) {
        this.planMny = planMny;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public Long getSafeteamcId() {
        return safeteamcId;
    }

    public void setSafeteamcId(Long safeteamcId) {
        this.safeteamcId = safeteamcId;
    }

    public String getSafeteamcName() {
        return safeteamcName;
    }

    public void setSafeteamcName(String safeteamcName) {
        this.safeteamcName = safeteamcName;
    }

    public String getSafeteamcBillCode() {
        return safeteamcBillCode;
    }

    public void setSafeteamcBillCode(String safeteamcBillCode) {
        this.safeteamcBillCode = safeteamcBillCode;
    }

    public Date getSafeteamcDate() {
        return safeteamcDate;
    }

    public void setSafeteamcDate(Date safeteamcDate) {
        this.safeteamcDate = safeteamcDate;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getSubmitEmployeeId() {
        return submitEmployeeId;
    }

    public void setSubmitEmployeeId(Long submitEmployeeId) {
        this.submitEmployeeId = submitEmployeeId;
    }

    public String getSubmitEmployeeName() {
        return submitEmployeeName;
    }

    public void setSubmitEmployeeName(String submitEmployeeName) {
        this.submitEmployeeName = submitEmployeeName;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Date getSubmitDate() {
        return submitDate;
    }

    public void setSubmitDate(Date submitDate) {
        this.submitDate = submitDate;
    }

    public List<PlancDetailEntity> getPlancDetailList() {
        return plancDetailList;
    }

    public void setPlancDetailList(List<PlancDetailEntity> plancDetailList) {
        this.plancDetailList = plancDetailList;
    }

    public Long getListerId() {
        return listerId;
    }

    public void setListerId(Long listerId) {
        this.listerId = listerId;
    }

    public String getListerName() {
        return listerName;
    }

    public void setListerName(String listerName) {
        this.listerName = listerName;
    }

    public String getUrgencyDegreeName() {
        return urgencyDegreeName;
    }

    public void setUrgencyDegreeName(String urgencyDegreeName) {
        this.urgencyDegreeName = urgencyDegreeName;
    }

    public String getSecurityClassName() {
        return securityClassName;
    }

    public void setSecurityClassName(String securityClassName) {
        this.securityClassName = securityClassName;
    }
}
